Documentation
¶
Index ¶
- func Debug(msg string, fields ...map[string]interface{})
- func Debugf(format string, args ...interface{})
- func Error(msg string, fields ...map[string]interface{})
- func Errorf(format string, args ...interface{})
- func Fatal(msg string, fields ...map[string]interface{})
- func Fatalf(format string, args ...interface{})
- func Info(msg string, fields ...map[string]interface{})
- func Infof(format string, args ...interface{})
- func InitLogger() error
- func Warn(msg string, fields ...map[string]interface{})
- func Warnf(format string, args ...interface{})
- type LogLevel
- type Logger
- func (l *Logger) Close() error
- func (l *Logger) Debug(msg string, fields ...map[string]interface{})
- func (l *Logger) Debugf(format string, args ...interface{})
- func (l *Logger) Error(msg string, fields ...map[string]interface{})
- func (l *Logger) Errorf(format string, args ...interface{})
- func (l *Logger) Fatal(msg string, fields ...map[string]interface{})
- func (l *Logger) Fatalf(format string, args ...interface{})
- func (l *Logger) Info(msg string, fields ...map[string]interface{})
- func (l *Logger) Infof(format string, args ...interface{})
- func (l *Logger) Warn(msg string, fields ...map[string]interface{})
- func (l *Logger) Warnf(format string, args ...interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Debugf ¶
func Debugf(format string, args ...interface{})
Debugf logs a formatted debug message using the global logger
func Errorf ¶
func Errorf(format string, args ...interface{})
Errorf logs a formatted error message using the global logger
func Fatalf ¶
func Fatalf(format string, args ...interface{})
Fatalf logs a formatted fatal message using the global logger and exits
func Infof ¶
func Infof(format string, args ...interface{})
Infof logs a formatted info message using the global logger
Types ¶
type LogLevel ¶
type LogLevel int
LogLevel represents the severity of a log message
func ParseLogLevel ¶
ParseLogLevel converts a string to LogLevel
type Logger ¶
type Logger struct {
// contains filtered or unexported fields
}
Logger represents our custom logger
func NewBasicLogger ¶
NewBasicLogger creates a basic logger for fallback
Click to show internal directories.
Click to hide internal directories.